# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.resource_list_connector_spec import ResourceListConnectorSpec

class TestResourceListConnectorSpec(unittest.TestCase):
    """ResourceListConnectorSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceListConnectorSpec:
        """Test ResourceListConnectorSpec
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceListConnectorSpec`
        """
        model = ResourceListConnectorSpec()
        if include_optional:
            return ResourceListConnectorSpec(
                records = [
                    arthur_client.api_bindings.models.connector_spec.ConnectorSpec(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        connector_type = 'shield', 
                        name = '', 
                        temporary = True, 
                        fields = [
                            arthur_client.api_bindings.models.connector_spec_field_with_metadata.ConnectorSpecFieldWithMetadata(
                                key = '', 
                                value = '', 
                                d_type = 'string', 
                                is_sensitive = True, )
                            ], 
                        last_updated_by_user = arthur_client.api_bindings.models.user.User(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            organization_id = '', 
                            id = '', 
                            first_name = '', 
                            last_name = '', 
                            email = '', 
                            picture = '', 
                            user_type = 'user', 
                            data_plane_id = '', 
                            client_id = '', 
                            organization_name = '', ), 
                        connector_check_result = arthur_client.api_bindings.models.connector_check_result.ConnectorCheckResult(
                            connection_check_outcome = 'succeeded', 
                            failure_reason = '', ), 
                        project_id = '', 
                        data_plane_id = '', )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, )
            )
        else:
            return ResourceListConnectorSpec(
                records = [
                    arthur_client.api_bindings.models.connector_spec.ConnectorSpec(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        connector_type = 'shield', 
                        name = '', 
                        temporary = True, 
                        fields = [
                            arthur_client.api_bindings.models.connector_spec_field_with_metadata.ConnectorSpecFieldWithMetadata(
                                key = '', 
                                value = '', 
                                d_type = 'string', 
                                is_sensitive = True, )
                            ], 
                        last_updated_by_user = arthur_client.api_bindings.models.user.User(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            organization_id = '', 
                            id = '', 
                            first_name = '', 
                            last_name = '', 
                            email = '', 
                            picture = '', 
                            user_type = 'user', 
                            data_plane_id = '', 
                            client_id = '', 
                            organization_name = '', ), 
                        connector_check_result = arthur_client.api_bindings.models.connector_check_result.ConnectorCheckResult(
                            connection_check_outcome = 'succeeded', 
                            failure_reason = '', ), 
                        project_id = '', 
                        data_plane_id = '', )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, ),
        )
        """

    def testResourceListConnectorSpec(self):
        """Test ResourceListConnectorSpec"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.data_plane_association import DataPlaneAssociation

class TestDataPlaneAssociation(unittest.TestCase):
    """DataPlaneAssociation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DataPlaneAssociation:
        """Test DataPlaneAssociation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DataPlaneAssociation`
        """
        model = DataPlaneAssociation()
        if include_optional:
            return DataPlaneAssociation(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                data_plane_id = '',
                project_id = '',
                data_plane = arthur_client.api_bindings.models.data_plane.DataPlane(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    name = '', 
                    workspace_id = '', 
                    description = '', 
                    user_id = '', 
                    infrastructure = 'AWS', 
                    last_check_in_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    capabilities = arthur_client.api_bindings.models.data_plane_capabilities.DataPlaneCapabilities(
                        gen_ai_enabled = True, ), ),
                project = arthur_client.api_bindings.models.project.Project(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = '', 
                    name = '', 
                    description = '', 
                    workspace_id = '', 
                    total_artifacts = 56, )
            )
        else:
            return DataPlaneAssociation(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                data_plane_id = '',
                project_id = '',
        )
        """

    def testDataPlaneAssociation(self):
        """Test DataPlaneAssociation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.resource_list_custom_aggregation_test_result import ResourceListCustomAggregationTestResult

class TestResourceListCustomAggregationTestResult(unittest.TestCase):
    """ResourceListCustomAggregationTestResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceListCustomAggregationTestResult:
        """Test ResourceListCustomAggregationTestResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceListCustomAggregationTestResult`
        """
        model = ResourceListCustomAggregationTestResult()
        if include_optional:
            return ResourceListCustomAggregationTestResult(
                records = [
                    arthur_client.api_bindings.models.custom_aggregation_test_result.CustomAggregationTestResult(
                        test_run_id = '', 
                        metric_name = '', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        value = null, 
                        dimensions = [
                            arthur_client.api_bindings.models.dimension.Dimension(
                                name = '', 
                                value = '', )
                            ], )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, )
            )
        else:
            return ResourceListCustomAggregationTestResult(
                records = [
                    arthur_client.api_bindings.models.custom_aggregation_test_result.CustomAggregationTestResult(
                        test_run_id = '', 
                        metric_name = '', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        value = null, 
                        dimensions = [
                            arthur_client.api_bindings.models.dimension.Dimension(
                                name = '', 
                                value = '', )
                            ], )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, ),
        )
        """

    def testResourceListCustomAggregationTestResult(self):
        """Test ResourceListCustomAggregationTestResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.alert_group import AlertGroup

class TestAlertGroup(unittest.TestCase):
    """AlertGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AlertGroup:
        """Test AlertGroup
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AlertGroup`
        """
        model = AlertGroup()
        if include_optional:
            return AlertGroup(
                alert_rule_id = '',
                alert_rule_name = '',
                count = 56,
                latest_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                model_id = '',
                model_name = '',
                bound = 'upper_bound',
                alerts = [
                    arthur_client.api_bindings.models.alert.Alert(
                        description = '', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        value = 1.337, 
                        threshold = 1.337, 
                        bound = 'upper_bound', 
                        interval = arthur_client.api_bindings.models.alert_rule_interval.AlertRuleInterval(
                            unit = 'seconds', 
                            count = 56, ), 
                        dimensions = arthur_client.api_bindings.models.dimensions.dimensions(), 
                        alert_rule_id = '', 
                        job_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        model_id = '', 
                        alert_rule_name = '', 
                        alert_rule_metric_name = '', 
                        is_duplicate_of = '', )
                    ]
            )
        else:
            return AlertGroup(
                alert_rule_id = '',
                alert_rule_name = '',
                count = 56,
                latest_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                model_id = '',
                model_name = '',
                bound = 'upper_bound',
                alerts = [
                    arthur_client.api_bindings.models.alert.Alert(
                        description = '', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        value = 1.337, 
                        threshold = 1.337, 
                        bound = 'upper_bound', 
                        interval = arthur_client.api_bindings.models.alert_rule_interval.AlertRuleInterval(
                            unit = 'seconds', 
                            count = 56, ), 
                        dimensions = arthur_client.api_bindings.models.dimensions.dimensions(), 
                        alert_rule_id = '', 
                        job_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        model_id = '', 
                        alert_rule_name = '', 
                        alert_rule_metric_name = '', 
                        is_duplicate_of = '', )
                    ],
        )
        """

    def testAlertGroup(self):
        """Test AlertGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
